Welcome to ClientVPS Mirrors

Help for package csppData
Type: Package
Title: Data Only: The Correlates of State Policy Project Dataset
Version: 0.2.61
Author: Caleb Lucas (https://caleblucas.com/) and Joshua McCrain (http://joshuamccrain.com/)
Maintainer: Caleb Lucas <calebjlucas@gmail.com>
Description: Contains the Correlates of State Policy Project dataset (+ codebook) assembled by Marty P. Jordan and Matt Grossmann (2020) http://ippsr.msu.edu/public-policy/correlates-state-policy used by the 'cspp' package. The Correlates data contains over 3000 variables across more than 100 years that pertain to state politics and policy in the United States.
License: GPL-3
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
Language: en-US
Depends: R (≥ 3.50)
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2022-05-13 22:14:08 UTC; caleblucas
Repository: CRAN
Date/Publication: 2022-05-16 07:00:02 UTC

The Correlates of State Policy Project Dataset Codebook

Description

The codebook for the Correlates of State Policy Project dataset (version 2.4.1) assembled by Marty P. Jordan and Matt Grossmann (2020) <http://ippsr.msu.edu/public-policy/correlates-state-policy>. Each observation is a variable in the CSPP dataset. The columns contain information regarding each variable, such as its source, citation, and a short & long description.

Usage

codebook

Format

An object of class data.frame with 3014 rows and 14 columns.

Details

@name codebook

@docType data

@usage data(codebook)

@keywords datasets


The Correlates of State Policy Project Dataset (IPPSR)

Description

The Correlates of State Policy Project dataset (version 2.4.1) assembled by Marty P. Jordan and Matt Grossmann (2020) <http://ippsr.msu.edu/public-policy/correlates-state-policy>. Each observation is a state-year.

Usage

correlates

Format

An object of class tbl_df (inherits from tbl, data.frame) with 6171 rows and 3020 columns.

Details

@name correlates

@docType data

@usage data(correlates)

@keywords datasets

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.